==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/ClusterControl/src/com/clustercontrol/bean/ExclusionConstant.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.bean;

import com.clustercontrol.util.Messages;

/**
 * 饹
 * 
 * @version 2.1.0
 * @since 1.0.0
 */
public class ExclusionConstant {
    /** ʤ */
    public static final int TYPE_NO = 0;

    /** ǽ */
    public static final int TYPE_FREQUENCY = 1;

    /** ֤ǽʬñ̡ */
    public static final int TYPE_PERIOD = 2;

    /** ٤ǽ */
    public static final int TYPE_PRIORITY = 3;
    
    /** ʤ */
    public static final String STRING_NO = Messages
            .getString("suppress.no");

    /** ǽ */
    public static final String STRING_FREQUENCY = Messages
            .getString("suppress.by.counter");

    /** ֤ǽʬñ̡ */
    public static final String STRING_PERIOD = Messages
            .getString("suppress.by.time.interval");

    /** ٤ǽ */
    public static final String STRING_PRIORITY = Messages
            .getString("suppress.by.priority");

    /**
     * ̤ʸѴ
     * 
     * @param type
     * @return
     */
    public static String typeToString(int type) {
        if (type == TYPE_NO) {
            return STRING_NO;
        } else if (type == TYPE_FREQUENCY) {
            return STRING_FREQUENCY;
        } else if (type == TYPE_PERIOD) {
            return STRING_PERIOD;
        } else if (type == TYPE_PRIORITY) {
            return STRING_PRIORITY;
        }
        return "";
    }

    /**
     * ʸ󤫤̤Ѵ
     * 
     * @param type
     * @return
     */
    public static int stringToType(String string) {
        if (string.equals(STRING_NO)) {
            return TYPE_NO;
        } else if (string.equals(STRING_FREQUENCY)) {
            return TYPE_FREQUENCY;
        } else if (string.equals(STRING_PERIOD)) {
            return TYPE_PERIOD;
        } else if (string.equals(STRING_PRIORITY)) {
            return TYPE_PRIORITY;
        }
        return -1;
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/ClusterControl/src/com/clustercontrol/bean/ExclusionConstant.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.bean;

import com.clustercontrol.util.Messages;

/**
 * 除外定数クラス
 * 
 * @version 2.1.0
 * @since 1.0.0
 */
public class ExclusionConstant {
    /** 処理しない */
    public static final int TYPE_NO = 0;

    /** 回数で除外する */
    public static final int TYPE_FREQUENCY = 1;

    /** 期間で除外する（分単位） */
    public static final int TYPE_PERIOD = 2;

    /** 重要度で除外する */
    public static final int TYPE_PRIORITY = 3;
    
    /** 処理しない */
    public static final String STRING_NO = Messages
            .getString("suppress.no");

    /** 回数で除外する */
    public static final String STRING_FREQUENCY = Messages
            .getString("suppress.by.counter");

    /** 期間で除外する（分単位） */
    public static final String STRING_PERIOD = Messages
            .getString("suppress.by.time.interval");

    /** 重要度で除外する */
    public static final String STRING_PRIORITY = Messages
            .getString("suppress.by.priority");

    /**
     * 種別から文字列に変換する
     * 
     * @param type
     * @return
     */
    public static String typeToString(int type) {
        if (type == TYPE_NO) {
            return STRING_NO;
        } else if (type == TYPE_FREQUENCY) {
            return STRING_FREQUENCY;
        } else if (type == TYPE_PERIOD) {
            return STRING_PERIOD;
        } else if (type == TYPE_PRIORITY) {
            return STRING_PRIORITY;
        }
        return "";
    }

    /**
     * 文字列から種別に変換する
     * 
     * @param type
     * @return
     */
    public static int stringToType(String string) {
        if (string.equals(STRING_NO)) {
            return TYPE_NO;
        } else if (string.equals(STRING_FREQUENCY)) {
            return TYPE_FREQUENCY;
        } else if (string.equals(STRING_PERIOD)) {
            return TYPE_PERIOD;
        } else if (string.equals(STRING_PRIORITY)) {
            return TYPE_PRIORITY;
        }
        return -1;
    }
}
